@@ -2,7 +2,11 @@
 
 mkdir -p /etc/xml
 [ -f /etc/xml/catalog ] || xmlcatalog --noout --create /etc/xml/catalog
+xmlcatalog --noout --add public \
+	"-//OASIS//DTD DocBook XML V4.2//EN" \
+	http://www.oasis-open.org/docbook/xml/4.2/ \
+	/etc/xml/catalog
 xmlcatalog --noout --add rewriteSystem \
 	http://www.oasis-open.org/docbook/xml/4.2/ \
-	/usr/share/docbook-xml42/ \
+	/usr/share/xml/docbook/4.2/ \
 	/etc/xml/catalog
